@@ -1,6 +1,9 @@
 #include "e.h"
 #include "e_mod_main.h"
 
+#include <sys/mman.h>
+#include <fcntl.h>
+
 /* gadcon requirements */
 static E_Gadcon_Client *_gc_init(E_Gadcon *gc, const char *name, const char *id, const char *style);
 static void             _gc_shutdown(E_Gadcon_Client *gcc);
@@ -36,6 +39,14 @@ typedef struct __Popup_Widgets
    Evas_Object *remaining;
    Evas_Object *health;
    Evas_Object *technology;
+
+   Evas_Object *drain;
+   Evas_Object *full;
+   Evas_Object *power;
+
+   Evas_Object *gr_bat;
+   Evas_Object *gr_pow;
+   Evas_Object *gr_crg;
 } _Popup_Widgets;
 
 typedef struct __Popup_Data
@@ -186,6 +197,68 @@ _gc_id_new(const E_Gadcon_Client_Class *client_class)
    return buf;
 }
 
+static inline const Battery_Hist_Entry *
+_battery_history_get(Battery *bat, int age)
+{
+// should not have to check
+//  if (age >= BATTERY_HIST_MAX) return NULL;
+  _battery_history_load(bat);
+  if (!bat->hist) return NULL;
+  int pos = (bat->hist->history_pos + age) % BATTERY_HIST_MAX;
+  return &(bat->hist->history[pos]);
+}
+
+static void
+_battery_history_store(Battery *bat, unsigned long long tim, int full, int mwatts, Eina_Bool ac, Eina_Bool charging)
+{
+  // last timepoint
+  unsigned long long tprev;
+  unsigned short hpos;
+
+  _battery_history_load(bat);
+  if (!bat->hist) return;
+  hpos = bat->hist->history_pos;
+  tprev = bat->hist->history[hpos].timepoint;
+  // 10 sec resoolution
+  if ((tim - tprev) < 10) return;
+  // bump pos with wrap-around
+  hpos = (hpos + BATTERY_HIST_MAX - 1) % BATTERY_HIST_MAX;
+  bat->hist->history_pos = hpos;
+  // store time and values
+  bat->hist->history[hpos].timepoint = tim;
+  bat->hist->history[hpos].full = full;
+  mwatts /= 100000;
+  if (mwatts > 65000) mwatts = 65000;
+  bat->hist->history[hpos].power_now = mwatts;
+  bat->hist->history[hpos].ac = ac;
+  bat->hist->history[hpos].charging = charging;
+  if (bat->hist->history[hpos].power_now > bat->history_power_now_max)
+    bat->history_power_now_max = bat->hist->history[hpos].power_now;
+}
+
+static double
+_battery_wattage_get(Battery *bat, unsigned long long timeperiod)
+{
+  int i = 0;
+  const Battery_Hist_Entry *h0, *h1;
+  int diff;
+
+  h0 = _battery_history_get(bat, i);
+  if ((!h0) || (h0->timepoint == 0)) return -1.0;
+  for (;;)
+    {
+      i++;
+      h1 = _battery_history_get(bat, i);
+      if ((!h1) || (h1->timepoint == 0)) return -1.0;
+      if ((h0->timepoint - h1->timepoint) >= timeperiod) break;
+    }
+  diff = h0->full - h1->full;
+  if (diff < 0) diff = -diff;
+  return
+    (double)(bat->last_full_charge * diff * 3600) /
+    (10000.0 * 1000000.0 * (double)timeperiod);
+}
+
 static void
 _battery_popup_usage_destroy(Instance *inst)
 {
@@ -228,15 +301,16 @@ _battery_popup_usage_content_update_cb(void *data)
      {
         _Popup_Widgets *w = &pd->widgets[i++];
 
-        elm_progressbar_value_set(w->pb_usage, (double) bat->percent / 100.0);
+        elm_progressbar_value_set(w->pb_usage, (double) bat->percent / 10000.0);
 
-        t = bat->time_left;
-        if ((battery_config->have_power) && (battery_config->full < 100))
+        if ((battery_config->have_power) && (battery_config->full < 10000))
           {
+             t = bat->time_full;
              elm_object_text_set(w->state, _("Charging"));
           }
-        else if ((!battery_config->have_power) && (battery_config->full < 100))
+        else if ((!battery_config->have_power) && (battery_config->full < 10000))
           {
+             t = bat->time_left;
              elm_object_text_set(w->state, _("Discharging"));
           }
         else
@@ -263,6 +337,111 @@ _battery_popup_usage_content_update_cb(void *data)
           elm_object_text_set(w->technology, bat->technology);
         else
           elm_object_text_set(w->technology, _("Unknown"));
+
+        if (bat->is_micro_watts)
+          {
+            // over the past 5 mins
+            double watts = _battery_wattage_get(bat, 60);
+
+            if (watts >= 0.0)
+              {
+                snprintf(buf, sizeof(buf), "%1.2fW", watts);
+                elm_object_text_set(w->drain, buf);
+              }
+            else
+              elm_object_text_set(w->drain, _("Unknown"));
+          }
+        else
+          elm_object_text_set(w->drain, _("Unknown"));
+
+        if (bat->is_micro_watts)
+          {
+            double wh = (double)bat->last_full_charge / 1000000.0;
+            snprintf(buf, sizeof(buf), "%1.2fWh", wh);
+            elm_object_text_set(w->full, buf);
+          }
+        else
+          elm_object_text_set(w->full, _("Unknown"));
+
+        if (bat->is_micro_watts)
+          {
+            double watt = (double)bat->power_now / 1000000.0;
+            snprintf(buf, sizeof(buf), "%1.2fW", watt);
+            elm_object_text_set(w->power, buf);
+          }
+        else
+          elm_object_text_set(w->power, _("Unknown"));
+
+         {
+           int *v_full, *v_pow, *v_crg, age;
+           unsigned int vals_num;
+           const Battery_Hist_Entry *bh;
+           unsigned long long time_now = time(NULL), td, tp;
+           int full_tot, pow_tot, crg_tot, tot, min_crg, max_crg, full0, full1;
+
+           e_graph_colorspec_set(w->gr_pow, "cc::selected-alt");
+           e_graph_colorspec_set(w->gr_bat, "cc::selected");
+
+           e_graph_colorspec_set(w->gr_crg, "cc::selected2");
+           e_graph_colorspec_down_set(w->gr_crg, "cc::selected4");
+
+           min_crg = -1;
+           max_crg = 1;
+           vals_num = 50;
+           v_full = calloc(vals_num, sizeof(int));
+           v_pow = calloc(vals_num, sizeof(int));
+           v_crg = calloc(vals_num, sizeof(int));
+           if ((v_full) && (v_pow) && (v_crg))
+             {
+               age = 0;
+               tp = 120;
+               for (i = 0; i < vals_num; i++)
+                 {
+                   full_tot = pow_tot = crg_tot = full0 = full1 = tot = 0;
+                   bh = _battery_history_get(bat, age);
+                   if (bh) full1 = bh->full;
+                   full0 = full1;
+                   for (;;)
+                     {
+                       bh = _battery_history_get(bat, age);
+                       if (!bh) break;
+                       td = time_now - bh->timepoint;
+                       if (td < tp)
+                         {
+                           full0 = bh->full;
+                           full_tot += bh->full;
+                           pow_tot += bh->power_now;
+                           tot++;
+                           age++;
+                         }
+                       else break;
+                     }
+                   if (!bh)
+                     {
+                       bh = _battery_history_get(bat, age - 1);
+                       if (bh) full0 = bh->full;
+                     }
+                   if (tot > 0)
+                     {
+                       crg_tot = full1 - full0;
+                       v_pow[vals_num - i - 1] = pow_tot / tot;
+                       v_full[vals_num - i - 1] = full_tot / tot;
+                       v_crg[vals_num - i - 1] = crg_tot / tot;
+                       if (v_crg[vals_num - i - 1] < min_crg)
+                         min_crg = v_crg[vals_num - i - 1];
+                       if (v_crg[vals_num - i - 1] > max_crg)
+                         max_crg = v_crg[vals_num - i - 1];
+                     }
+                   tp += 120; // 1 val == 120 sec
+                 }
+               e_graph_values_set(w->gr_pow, vals_num, v_pow, 0, bat->history_power_now_max);
+               e_graph_values_set(w->gr_bat, vals_num, v_full, 0, 10000);
+               e_graph_values_set(w->gr_crg, vals_num, v_crg, min_crg, max_crg);
+             }
+           free(v_full);
+           free(v_pow);
+           free(v_crg);
+        }
         if (i == (pd->n_units - 1)) break;
      }
    return ECORE_CALLBACK_RENEW;
@@ -308,7 +487,7 @@ _content_get(void *data, Evas_Object *obj, const char *part)
    o = evas_object_rectangle_add(evas_object_evas_get(obj));
    evas_object_size_hint_align_set(o, EVAS_HINT_FILL, 0.5);
    evas_object_size_hint_weight_set(o, 1.0, 0);
-   evas_object_size_hint_min_set(o, ELM_SCALE_SIZE(220), ELM_SCALE_SIZE(20));
+   evas_object_size_hint_min_set(o, ELM_SCALE_SIZE(280), ELM_SCALE_SIZE(20));
    elm_table_pack(tb, o, 0, 0, 8, 1);
 
    w->pb_usage = o = elm_progressbar_add(obj);
@@ -331,7 +510,6 @@ _content_get(void *data, Evas_Object *obj, const char *part)
    elm_table_pack(tb, o, 1, 1, 1, 1);
    evas_object_show(o);
 
-
    o = elm_icon_add(obj);
    elm_icon_standard_set(o, "clock");
    evas_object_size_hint_min_set(o, ELM_SCALE_SIZE(20), ELM_SCALE_SIZE(20));
@@ -344,7 +522,6 @@ _content_get(void *data, Evas_Object *obj, const char *part)
    elm_table_pack(tb, o, 3, 1, 1, 1);
    evas_object_show(o);
 
-
    o = elm_icon_add(obj);
    elm_icon_standard_set(o, "health");
    evas_object_size_hint_min_set(o, ELM_SCALE_SIZE(20), ELM_SCALE_SIZE(20));
@@ -357,7 +534,6 @@ _content_get(void *data, Evas_Object *obj, const char *part)
    elm_table_pack(tb, o, 5, 1, 1, 1);
    evas_object_show(o);
 
-
    o = elm_icon_add(obj);
    elm_icon_standard_set(o, "tech");
    evas_object_size_hint_min_set(o, ELM_SCALE_SIZE(20), ELM_SCALE_SIZE(20));
@@ -370,6 +546,86 @@ _content_get(void *data, Evas_Object *obj, const char *part)
    elm_table_pack(tb, o, 7, 1, 1, 1);
    evas_object_show(o);
 
+
+   o = elm_icon_add(obj);
+   elm_icon_standard_set(o, "battery-good-charging");
+   evas_object_size_hint_min_set(o, ELM_SCALE_SIZE(20), ELM_SCALE_SIZE(20));
+   elm_table_pack(tb, o, 0, 2, 1, 1);
+   evas_object_show(o);
+
+   w->drain = o = elm_label_add(obj);
+   evas_object_size_hint_align_set(o, 0.0, 0.5);
+   evas_object_size_hint_weight_set(o, 1.0, 0);
+   elm_table_pack(tb, o, 1, 2, 1, 1);
+   evas_object_show(o);
+
+   o = elm_icon_add(obj);
+   elm_icon_standard_set(o, "battery-full");
+   evas_object_size_hint_min_set(o, ELM_SCALE_SIZE(20), ELM_SCALE_SIZE(20));
+   elm_table_pack(tb, o, 2, 2, 1, 1);
+   evas_object_show(o);
+
+   w->full = o = elm_label_add(obj);
+   evas_object_size_hint_align_set(o, 0.0, 0.5);
+   evas_object_size_hint_weight_set(o, 1.0, 0);
+   elm_table_pack(tb, o, 3, 2, 1, 1);
+   evas_object_show(o);
+
+   o = elm_icon_add(obj);
+   elm_icon_standard_set(o, "battery-empty-charging");
+   evas_object_size_hint_min_set(o, ELM_SCALE_SIZE(20), ELM_SCALE_SIZE(20));
+   elm_table_pack(tb, o, 4, 2, 1, 1);
+   evas_object_show(o);
+
+   w->power = o = elm_label_add(obj);
+   evas_object_size_hint_align_set(o, 0.0, 0.5);
+   evas_object_size_hint_weight_set(o, 1.0, 0);
+   elm_table_pack(tb, o, 5, 2, 1, 1);
+   evas_object_show(o);
+
+
+   w->gr_bat = o = e_graph_add(obj);
+   evas_object_size_hint_align_set(o, EVAS_HINT_FILL, EVAS_HINT_FILL);
+   evas_object_size_hint_weight_set(o, 1.0, 0.0);
+   evas_object_size_hint_min_set(o, ELM_SCALE_SIZE(80), ELM_SCALE_SIZE(40));
+   elm_table_pack(tb, o, 0, 3, 8, 1);
+   evas_object_show(o);
+
+   o = elm_label_add(obj);
+   elm_object_text_set(o, _("Level"));
+   evas_object_size_hint_align_set(o, 0.0, 0.0);
+   evas_object_size_hint_weight_set(o, 1.0, 0);
+   elm_table_pack(tb, o, 1, 3, 1, 1);
+   evas_object_show(o);
+
+   w->gr_pow = o = e_graph_add(obj);
+   evas_object_size_hint_align_set(o, EVAS_HINT_FILL, EVAS_HINT_FILL);
+   evas_object_size_hint_weight_set(o, 1.0,  1.0);
+   evas_object_size_hint_min_set(o, ELM_SCALE_SIZE(80), ELM_SCALE_SIZE(40));
+   elm_table_pack(tb, o, 0, 4, 8, 1);
+   evas_object_show(o);
+
+   o = elm_label_add(obj);
+   elm_object_text_set(o, _("Energy"));
+   evas_object_size_hint_align_set(o, 0.0, 0.0);
+   evas_object_size_hint_weight_set(o, 1.0, 0);
+   elm_table_pack(tb, o, 1, 4, 1, 1);
+   evas_object_show(o);
+
+   w->gr_crg = o = e_graph_add(obj);
+   evas_object_size_hint_align_set(o, EVAS_HINT_FILL, EVAS_HINT_FILL);
+   evas_object_size_hint_weight_set(o, 1.0,  1.0);
+   evas_object_size_hint_min_set(o, ELM_SCALE_SIZE(80), ELM_SCALE_SIZE(40));
+   elm_table_pack(tb, o, 0, 5, 8, 1);
+   evas_object_show(o);
+
+   o = elm_label_add(obj);
+   elm_object_text_set(o, _("(Dis)charge"));
+   evas_object_size_hint_align_set(o, 0.0, 0.0);
+   evas_object_size_hint_weight_set(o, 1.0, 0);
+   elm_table_pack(tb, o, 1, 5, 1, 1);
+   evas_object_show(o);
+
    return tb;
 }
 
@@ -400,8 +656,8 @@ _battery_popup_usage_new(Instance *inst)
    evas_object_show(tb);
 
    rec = evas_object_rectangle_add(evas_object_evas_get(base));
-   evas_object_size_hint_min_set(rec, ELM_SCALE_SIZE(360), ELM_SCALE_SIZE(160));
-   evas_object_size_hint_max_set(rec, ELM_SCALE_SIZE(560), ELM_SCALE_SIZE(400));
+   evas_object_size_hint_min_set(rec, ELM_SCALE_SIZE(400), ELM_SCALE_SIZE(280));
+   evas_object_size_hint_max_set(rec, ELM_SCALE_SIZE(560), ELM_SCALE_SIZE(450));
    elm_table_pack(tb, rec, 0, 0, 1, 1);
 
    glist = elm_genlist_add(base);
@@ -589,9 +845,9 @@ _battery_device_update(void)
    int have_battery = 0;
    int have_power = 0;
    int charging = 0;
-
    int batnum = 0;
    int acnum = 0;
+   unsigned long long tim = time(NULL);
 
    EINA_LIST_FOREACH(device_ac_adapters, l, ac)
      {
@@ -613,9 +869,9 @@ _battery_device_update(void)
         if (bat->percent >= 0)
           full += bat->percent;
         else if (bat->last_full_charge > 0)
-          full += (bat->current_charge * 100) / bat->last_full_charge;
+          full += (bat->current_charge * 10000) / bat->last_full_charge;
         else if (bat->design_charge > 0)
-          full += (bat->current_charge * 100) / bat->design_charge;
+          full += (bat->current_charge * 10000) / bat->design_charge;
         if (bat->time_left > 0)
           {
              if (time_left < 0) time_left = bat->time_left;
@@ -627,13 +883,16 @@ _battery_device_update(void)
              else time_full += bat->time_full;
           }
         charging += bat->charging;
+        _battery_history_store(bat, tim,
+                               full, bat->power_now,
+                               have_power, bat->charging);
      }
 
    if ((device_batteries) && (batnum == 0))
      return;  /* not ready yet, no properties received for any battery */
 
    if (batnum > 0) full /= batnum;
-   if ((full == 100) && have_power)
+   if ((full == 10000) && have_power)
      {
         time_left = -1;
         time_full = -1;
@@ -685,9 +944,8 @@ _battery_config_updated(void)
    if ((battery_config->force_mode == UNKNOWN) ||
        (battery_config->force_mode == NOSUBSYSTEM))
      {
-        snprintf(buf, sizeof(buf), "%s/%s/batget %i",
-                 e_module_dir_get(battery_config->module), MODULE_ARCH,
-                 battery_config->poll_interval);
+        snprintf(buf, sizeof(buf), "%s/%s/batget",
+                 e_module_dir_get(battery_config->module), MODULE_ARCH);
 
         battery_config->batget_exe =
           ecore_exe_pipe_run(buf, ECORE_EXE_PIPE_READ |
@@ -845,7 +1103,7 @@ _battery_update(int full, int time_left, int time_full, Eina_Bool have_battery,
                edje_object_signal_emit(inst->o_battery, "e,state,ac,on", "e");
              else
                edje_object_signal_emit(inst->o_battery, "e,state,ac,off", "e");
-             if (have_power && (full < 100))
+             if (have_power && (full < 10000))
                {
                   edje_object_signal_emit(inst->o_battery, "e,state,charging", "e");
                   if (inst->popup_battery)
@@ -864,8 +1122,8 @@ _battery_update(int full, int time_left, int time_full, Eina_Bool have_battery,
                {
                   double val;
 
-                  if (full >= 100) val = 1.0;
-                  else val = (double)full / 100.0;
+                  if (full >= 10000) val = 1.0;
+                  else val = (double)full / 10000.0;
                   _battery_face_level_set(inst->o_battery, val);
                   if (inst->popup_battery)
                     _battery_face_level_set(inst->popup_battery, val);
@@ -898,7 +1156,7 @@ _battery_update(int full, int time_left, int time_full, Eina_Bool have_battery,
           }
         if (have_battery &&
             (!have_power) &&
-            (full < 100) &&
+            (full < 10000) &&
             (
               (
                 (time_left > 0) &&
@@ -917,7 +1175,7 @@ _battery_update(int full, int time_left, int time_full, Eina_Bool have_battery,
              printf("-------------------------------------- bat warn .. why below\n");
              printf("have_battery = %i\n", (int)have_battery);
              printf("have_power = %i\n", (int)have_power);
-             printf("full = %i\n", (int)full);
+             printf("full = %i\n", (int)full / 100);
              printf("time_left = %i\n", (int)time_left);
              printf("battery_config->alert = %i\n", (int)battery_config->alert);
              printf("battery_config->alert_p = %i\n", (int)battery_config->alert_p);
@@ -926,19 +1184,19 @@ _battery_update(int full, int time_left, int time_full, Eina_Bool have_battery,
                {
                   printf("t-debounce = %3.3f\n", (t - debounce_time));
                   debounce_time = t;
-                  if (((t - init_time) > 5.0) && (full < 15))
-                    _battery_warning_popup(inst, time_left, (double)full / 100.0);
+                  if (((t - init_time) > 5.0) && (full < 1500))
+                    _battery_warning_popup(inst, time_left, (double)full / 10000.0);
                }
           }
         else if (have_power || ((time_left / 60) > battery_config->alert))
           _battery_warning_popup_destroy(inst);
         if ((have_battery) && (!have_power) && (full >= 0) &&
             (battery_config->suspend_below > 0) &&
-            (full < battery_config->suspend_below))
+            (full < battery_config->suspend_below / 100))
           {
-             printf("battery %i suspend below %i\n", full, battery_config->suspend_below);
+             printf("battery %i suspend below %i\n", full / 100, battery_config->suspend_below);
              if (battery_config->suspend_method == SUSPEND)
-               e_sys_action_do(E_SYS_SUSPEND, NULL);
+               e_sys_action_do(E_SYS_SUSPEND_MODE, NULL);
              else if (battery_config->suspend_method == HIBERNATE)
                e_sys_action_do(E_SYS_HIBERNATE, NULL);
              else if (battery_config->suspend_method == SHUTDOWN)
@@ -951,9 +1209,9 @@ _battery_update(int full, int time_left, int time_full, Eina_Bool have_battery,
      {
         if (have_power)
           e_powersave_mode_set(E_POWERSAVE_MODE_LOW);
-        else if (full > 95)
+        else if (full > 9500)
           e_powersave_mode_set(E_POWERSAVE_MODE_MEDIUM);
-        else if (full > 30)
+        else if (full > 3000)
           e_powersave_mode_set(E_POWERSAVE_MODE_HIGH);
         else
           e_powersave_mode_set(E_POWERSAVE_MODE_EXTREME);
@@ -1031,6 +1289,77 @@ _battery_cb_exe_del(void *data EINA_UNUSED, int type EINA_UNUSED, void *event)
    return ECORE_CALLBACK_PASS_ON;
 }
 
+static void
+_battery_history_file_reset(int fd)
+{
+  int val;
+
+  ftruncate(fd, 0);
+  ftruncate(fd, sizeof(Battery_Hist));
+  lseek(fd, 0, SEEK_SET);
+  val = BATTERY_HISTORY_MAGIC;
+  write(fd, &val, sizeof(val));
+  val = BATTERY_HISTORY_VERSION;
+  write(fd, &val, sizeof(val));
+  // rest is zero
+}
+
+static void
+_battery_history_file_map(Battery *bat, int fd)
+{
+  bat->hist = mmap(NULL, sizeof(Battery_Hist), PROT_READ | PROT_WRITE, MAP_SHARED, fd, 0);
+  if ((bat->hist == MAP_FAILED) || (bat->hist == NULL))
+    { // yes i know - not correct but nothing will sensibly mmap at addr 0/NULL
+      if (bat->hist == NULL) munmap(bat->hist, sizeof(Battery_Hist));
+      bat->hist = NULL;
+    }
+}
+
+void
+_battery_history_load(Battery *bat)
+{
+  char buf[PATH_MAX];
+  int fd, i;
+  off_t off;
+
+  if (bat->hist) return;
+  // XXX: some unique host id needed ?
+  e_user_dir_concat_static(buf, "battery-history.dat");
+  fd = open(buf, O_RDWR | O_EXCL, S_IRUSR | S_IWUSR);
+  if (fd < 0) fd = open(buf, O_RDWR | O_EXCL | O_CREAT, S_IRUSR | S_IWUSR);
+  if (fd < 0) return;
+  off = lseek(fd, 0, SEEK_END);
+  if (off != sizeof(Battery_Hist)) _battery_history_file_reset(fd);
+  _battery_history_file_map(bat, fd);
+  if (!bat->hist) goto end;
+  if ((bat->hist->magic != BATTERY_HISTORY_MAGIC) ||
+      (bat->hist->version != BATTERY_HISTORY_VERSION) ||
+      (bat->hist->history_pos >= BATTERY_HIST_MAX))
+    {
+      munmap(bat->hist, sizeof(Battery_Hist));
+      _battery_history_file_reset(fd);
+      _battery_history_file_map(bat, fd);
+      if (!bat->hist) goto end;
+    }
+  bat->history_power_now_max = 0;
+  for (i = 0; i < BATTERY_HIST_MAX; i++)
+    {
+      if (bat->hist->history[i].power_now > bat->history_power_now_max)
+      bat->history_power_now_max = bat->hist->history[i].power_now;
+    }
+end:
+  close(fd); // we can close fd once we have our mapping
+}
+
+void
+_battery_history_close(Battery *bat)
+{
+  if (!bat->hist) return;
+  munmap(bat->hist, sizeof(Battery_Hist));
+  bat->hist = NULL;
+}
+
+
 /* module setup */
 E_API E_Module_Api e_modapi =
 {
@@ -1045,7 +1374,6 @@ e_modapi_init(E_Module *m)
 #undef D
 #define T Config
 #define D conf_edd
-   E_CONFIG_VAL(D, T, poll_interval, INT);
    E_CONFIG_VAL(D, T, alert, INT);
    E_CONFIG_VAL(D, T, alert_p, INT);
    E_CONFIG_VAL(D, T, alert_timeout, INT);
@@ -1060,7 +1388,6 @@ e_modapi_init(E_Module *m)
    if (!battery_config)
      {
         battery_config = E_NEW(Config, 1);
-        battery_config->poll_interval = 512;
         battery_config->alert = 30;
         battery_config->alert_p = 10;
         battery_config->alert_timeout = 0;
@@ -1071,7 +1398,6 @@ e_modapi_init(E_Module *m)
 #endif
         battery_config->desktop_notifications = 0;
      }
-   E_CONFIG_LIMIT(battery_config->poll_interval, 4, 4096);
    E_CONFIG_LIMIT(battery_config->alert, 0, 60);
    E_CONFIG_LIMIT(battery_config->alert_p, 0, 100);
    E_CONFIG_LIMIT(battery_config->alert_timeout, 0, 300);
